@@ -5,9 +5,14 @@ package Archive::Builder::Generators;
 
 use strict;
 use UNIVERSAL 'isa';
-use Class::Autouse qw{
-	File::Flat
-	};
+use Archive::Builder ();
+
+
+
+
+
+#####################################################################
+# Trvial Generators
 
 # Recieves as an argument the exact string the file should contain
 sub string {
@@ -64,6 +69,13 @@ sub handle {
 	}
 }	
 
+
+
+
+
+#####################################################################
+# Common Advanced Generators
+
 # The template generator will only work if the Template Toolkit is installed.
 # The first argument is an instantiation of a Template object.
 # The second argument is the file name withing the Template object.
